/**
 * 展示节点输入框组件。
 * Display input of node.
 *
 * @access public
 * @return void
 */
function showStepInput()
{
    $(this).closest('.add-btn-box').addClass('hidden');
    $('#stepNode').removeClass('hidden');

    setTimeout(function()
    {
        $('#stepNode').trigger('focus');
        document.getElementById("stepNode").addEventListener('blur', saveStepNode);
        document.getElementById("stepNode").addEventListener('keydown', function(e)
        {
            if(e.keyCode == 13) saveStepNode.call(this);
        });
    }, 1);
}

/**
 * 保存分析步骤节点。
 * Save node of think step.
 *
 * @access public
 * @return void
 */
function saveStepNode()
{
    const name = $(this).val();
    const {marketID, wizardID} = $('.think-step-content').data();
    if(!name)
    {
        $('.add-btn-box').removeClass('hidden');
        $('#stepNode').addClass('hidden');
        return;
    }

    $.ajaxSubmit({
        url:  $.createLink('thinkstep', 'ajaxCreate', `marketID=${marketID}`),
        data: {
            wizard: wizardID,
            title: name,
            parent: 0,
            objectID: 0,
            createType: 'child',
            type: 'node',
        },
        onSuccess: () => {
            $(this).val('');
        },
        onFail: (error) => {
            if(error?.message) zui.Modal.alert({message: error?.message.title});
        }
    });
}

/**
 * 提交分析步骤表单。
 * Submit think step form.
 *
 * @param  string   url
 * @param  function onSuccess
 * @access public
 * @return void
 */
function submitStepForm(url, onSuccess)
{
    const formData         = new FormData($('.think-step-form form')[0]);
    const minCountDisabled = $('.m-thinkstep-edit .min-count input').prop('disabled')
    const requiredDisabled = $('.m-thinkstep-edit .step-required  .check-list-inline').hasClass('disabled');

    /* 如果是否必填不可修改，则该题必填。如果最小值不可修改，则最小值为1。 */
    /* If it is mandatory and cannot be modified, then the question is mandatory. If the minimum value cannot be modified, then the minimum value is 1. */
    if(requiredDisabled) formData.append('options[required]', 1);
    if(minCountDisabled) formData.append('options[minCount]', 1);

    $.ajaxSubmit({
        url: url,
        data: formData,
        load: false,
        onSuccess: onSuccess,
        onFail: (error) => {
            if(error?.message) showValidateMessage(error.message);
        }
    });
}

/**
 * 切换视图页面。
 * Switch view page.
 *
 * @access public
 * @return void
 */
window.switchView = function()
{
    const {marketID, wizardID, stepID, mode} = $('.think-step-content').data();
    const locateUrl = $.createLink('thinkwizard', 'result', `marketID=${marketID}&wizardID=${wizardID}&stepID=${stepID}`);
    if(mode == 'create' || mode == 'detail') return loadPage(locateUrl);

    submitStepForm($.createLink('thinkstep', 'edit', `marketID=${marketID}&stepID=${stepID}`), () => {
        loadPage(locateUrl);
    });
}

/**
 * 发布分析模型。
 * Publish think Model.
 *
 * @access public
 * @return void
 */
window.publish = function()
{
    const {marketID, wizardID, stepID, mode} = $('.think-step-content').data();
    const locateUrl = $.createLink('thinkwizard', 'publish', `marketID=${marketID}&wizardID=${wizardID}`);
    if(mode == 'create' || mode == 'detail') return $.ajaxSubmit({url: locateUrl});

    submitStepForm($.createLink('thinkstep', 'edit', `marketID=${marketID}&stepID=${stepID}`), () => {
        $.ajaxSubmit({url: locateUrl});
    });
}

/**
 * 更新节点顺序。
 * Update the order of think step.
 *
 * @param  object event
 * @param  object orders
 * @access public
 * @return void
 */
window.updateOrder = function(event, orders)
{
    const {marketID, wizardID, stepID, sortErrorTip} = $('.think-step-content').data();
    let sortedIdList = {};
    for(let i in orders) sortedIdList['orders[' + orders[i] + ']'] = i;
    /* 判断更新的节点是否符合要求：被引用的节点不能在引用的节点上方。 */
    /* Determine whether the updated node meets the requirements: the referenced node cannot be above the referencing node. */
    $.post($.createLink('thinkstep', 'ajaxCanSort'), sortedIdList, function(response)
    {
        response = JSON.parse(response);
        const url = $.createLink('thinkstep', 'view', 'marketID='+ marketID + '&wizardID=' + wizardID + '&stepID=' + stepID);
        /* 如果可以更新节点顺序，则调用接口更新节点顺序；若不能更新节点顺序，则弹窗显示提示信息。 */
        /* If the node sequence can be updated, the interface is called to update the node sequence; if the node sequence cannot be updated, a pop-up window displays a prompt message. */
        if(response.result === 'success')
        {
            $.post($.createLink('thinkstep', 'ajaxUpdateOrder'), sortedIdList, function(response)
            {
                response = JSON.parse(response);
                if(response.result == 'success') openUrl(url);
            });
        }
        else
        {
            zui.Modal.alert({message: sortErrorTip, icon: 'icon-exclamation-sign', iconClass: 'warning-pale rounded-full icon-2x', size: 'sm', custom: {closeBtn: false}, onClickAction: function(){openUrl(url)}});
        }
    });
}
