<?php
/**
 * The link view file of thinkstep module of ZenTaoPMS.
 * @copyright   Copyright 2009-2023 禅道软件（青岛）有限公司(ZenTao Software (Qingdao) Co., Ltd. www.zentao.net)
 * @license     ZPL(https://zpl.pub/page/zplv12.html) or AGPL(https://www.gnu.org/licenses/agpl-3.0.en.html)
 * @author      Yu Zhang<zhangyu@easycorp.ltd>
 * @package     thinkstep
 * @link        https://www.zentao.net
 */
namespace zin;

$displayFormItems = [];
$showMethod       = $step->options->questionType === 'multicolumn' ? 1 : 0;
$onlyShowWhole    = in_array($step->options->questionType, $config->thinkstep->onlyWhole) || $step->options->questionType === 'multicolumn' && !empty($step->options->quoteTitle);
if($onlyShowWhole) $showMethod = 2;

$showMethod        = $step->link && $step->link->showMethod ? $step->link->showMethod : $showMethod;
$emptyShowMethod   = empty($step->link) || empty($step->link->showMethod);
$multicolumnBlocks = array();
$blocks            = array();
$multicolumnItems  = array();

if($onlyShowWhole)
{
    $displayFormItems[] = array('text' => $lang->thinkstep->displayForm[2], 'value' => '2');
}
else
{
    foreach($lang->thinkstep->displayForm as $index => $item)
    {
        $multicolumnDisabled = $index == '0' && $step->options->questionType === 'multicolumn';
        $radioDisabled       = $index == '1' && ($step->options->questionType === 'radio' || $step->options->questionType === 'checkbox');
        $displayFormItems[] = array(
            'text'     => $item,
            'value'    => $index,
            'disabled' => $multicolumnDisabled || $radioDisabled
        );
    }
}

foreach($wizard->blocks as $index => $item)
{
    $blocks[] = array('key' => $index + 1, 'value' => $index + 1, 'text' => $item);
}

if(!empty($step->options->fields))
{
    foreach($step->options->fields as $index => $item)
    {
        $multicolumnItems[] = array('key' => $index + 1, 'value' => $index + 1, 'text' => $item);
    }
}

if($step->link && !empty($step->link->columnBlock))
{
    foreach($step->link->column as $index => $item)
    {
        $multicolumnBlocks[] = div
        (
            setClass('bg-gray-100 px-6 py-4 flex items-center mb-2 multicolumn-link-item'),
            div($lang->thinkstep->label->linkCurrent),
            picker
            (
                setClass('select-column mx-2'),
                setStyle(array('max-width' => '116px')),
                set::name('column[]'),
                set::placeholder($lang->thinkstep->label->selectColumn),
                set::items(!empty($multicolumnItems) ? $multicolumnItems : array()),
                set::value($item),
                on::change('disabledSelectedColumn')
            ),
            div($lang->thinkstep->label->columnLinkBlock),
            picker
            (
                setClass('multicolumn-block ml-2'),
                setStyle(array('max-width' => '116px')),
                set::name('columnBlock[]'),
                set::placeholder($lang->thinkstep->placeholder->selectBlock),
                set::items($blocks),
                set::value($step->link->columnBlock[$index])
            ),
            btn(setClass('remove-condition bg-primary-100 w-4 h-4 text-primary ml-4 p-0.5 rounded-full', count($step->link->columnBlock) == 1 ? 'disabled' : ''), icon(setClass('text-sm'), 'close'), on::click()->call('removeCondition', jsRaw('this')))
        );
    }
}
formPanel
(
    setClass('link-block-form pb-10'),
    set::title($lang->thinkstep->linkSetting),
    set::actionsClass('link-actions w-full'),
    set::actions(
        array(
            array('text' => $lang->save, 'id' => 'save-button', 'class' => 'btn primary', 'btnType' => 'submit'),
            !$hiddenUnlink && !empty($step->link) ? array(
                'text'         => $lang->thinkstep->cancelLink,
                'id'           => 'cancel-button',
                'class'        => 'btn btn-wide',
                'data-url'     => inlink('cancelLink', "stepID=$step->id"),
                'data-confirm' => $lang->thinkstep->tips->cancelLink,
                'onclick'      => 'cancelLink()'
            ) : null,
        )
    ),
    empty($relatedSteps) ? div
    (
        setClass(' text-lg font-medium text-gray-900 text-ellipsis'),
        set::title($step->index . '. ' . $step->title),
        span(setClass('w-20 inline-block'), $lang->thinkstep->label->currentTopic),
        $step->index . '. ' . $step->title
    ) : formGroup
    (
        set::label($lang->thinkstep->label->selectQuestion),
        set::labelClass('display-form select-question overflow-visible'),
        setData(array('marketID' => $marketID, 'wizardID' => $wizard->id)),
        set::required(true),
        picker
        (
            setStyle(array('max-width' => '249px')),
            set::name('step'),
            set::placeholder($lang->thinkstep->placeholder->selectQuestion),
            set::required(true),
            set::value($step->id),
            set::items($relatedSteps),
            on::change()->call('selectQuestion')
        )
    ),
    formRow
    (
        formGroup
        (
            set::label($lang->thinkstep->label->displayForm),
            set::labelClass('display-form'),
            radioList
            (
                setClass('show-method'),
                set::name('showMethod'),
                set::inline(true),
                set::items($displayFormItems),
                set::value($showMethod),
                on::change()
                    ->const('multicolumn', $step->options->questionType === 'multicolumn')
                    ->toggleClass('.question-link', 'hidden', 'target.value !=2')
                    ->toggleClass('.result-item-link', 'hidden', 'target.value != 0')
                    ->toggleClass('.radio-link-content', 'hidden', 'target.value == 1')
                    ->toggleClass('.multicolumn-link-content', 'hidden', 'target.value != 1')
                    ->do("
                        if($('.link-block-error').length > 0) { $('.link-block-error').removeClass('link-block-error'); }
                        if($('.link-tips').length > 0) { $('.link-tips').addClass('hidden'); }
                    ")
            )
        )
    ),
    div
    (
        setClass('bg-gray-100 px-6 py-4 radio-link-content', $showMethod == 1 ? 'hidden' : ''),
        div
        (
            setClass('result-item-link', $showMethod != 0 ? 'hidden' : ''),
            div
            (
                setClass('flex item-center'),
                div(
                    setClass('text-right flex-none w-52 pr-2 leading-8'),
                    html($lang->thinkstep->label->linkSelected)
                ),
                picker
                (
                    setClass('selected-block'),
                    setStyle(array('max-width' => '116px')),
                    setdata('unSelectedItem', $blocks),
                    set::name('selectedBlock'),
                    set::placeholder($lang->thinkstep->placeholder->selectBlock),
                    set::items($blocks),
                    set::value($step->link && $step->link->selectedBlock ? $step->link->selectedBlock : null),
                    on::inited()->call('changeSelectedBlock'),
                    on::change()->call('changeSelectedBlock')
                )
            ),
            div
            (
                setClass('flex item-center mt-3'),
                div(
                    setClass('text-right flex-none w-52 pr-2 leading-8'),
                    html($lang->thinkstep->label->linkNonSelected)
                ),
                picker
                (
                    setClass('unselected-block'),
                    setStyle(array('max-width' => '116px')),
                    set::name('unSelectedBlock'),
                    set::placeholder($lang->thinkstep->placeholder->selectBlock),
                    set::items($blocks),
                    set::value($step->link && $step->link->unSelectedBlock ? $step->link->unSelectedBlock : null),
                    on::inited()->call('changeUnSelectedBlock'),
                    on::change()->call('changeUnSelectedBlock')
                )
            )
        ),
        div(setClass('question-link', ((empty($step->link) || $step->link->showMethod != 2) && $showMethod != 2) ? 'hidden' : ''), div
        (
            setClass('flex item-center'),
            div(
                setClass('text-right flex-none w-40 pr-2 leading-8'),
                $lang->thinkstep->label->questionLinkBlocks
            ),
            picker(setClass('question-block'), setStyle(array('max-width' => '116px')), set::name('questionBlocks'), set::placeholder($lang->thinkstep->placeholder->selectBlock), set::items($blocks), set::value($step->link && $step->link->questionBlocks ? $step->link->questionBlocks : null))
        ))
    ),
    div(setClass('multicolumn-link-content', $showMethod != 1 ? 'hidden' : ''), $multicolumnBlocks, div
    (
        setClass('bg-gray-100 px-6 py-4 flex items-center mb-2 ', !empty($multicolumnBlocks) ? 'hidden' : 'multicolumn-link-item'),
        div($lang->thinkstep->label->linkCurrent),
        picker
        (
            setClass('select-column mx-2'),
            setStyle(array('max-width' => '116px')),
            set::name('column[]'),
            set::placeholder($lang->thinkstep->label->selectColumn),
            set::items(!empty($multicolumnItems) ? $multicolumnItems : array()),
            on::change('disabledSelectedColumn')
        ),
        div($lang->thinkstep->label->columnLinkBlock),
        picker(setClass('multicolumn-block ml-2'), setStyle(array('max-width' => '116px')), set::name('columnBlock[]'), set::placeholder($lang->thinkstep->placeholder->selectBlock), set::items($blocks)),
        btn(setClass('remove-condition bg-primary-100 w-4 h-4 text-primary ml-4 p-0.5 rounded-full disabled'), icon(setClass('text-sm'), 'close'), on::click()->call('removeCondition', jsRaw('this')))
    ), div
    (
        setClass('bg-gray-100 px-6 py-4 flex items-center mb-2 multicolumn-link-template hidden'),
        setData('columnOption', ($step->options->questionType === 'multicolumn' && !empty($multicolumnItems)) ? $multicolumnItems : array()),
        setData('blocksOptions', $blocks),
        setData('selectColumnPlaceholder', $lang->thinkstep->label->selectColumn),
        setData('selectBlockPlaceholder', $lang->thinkstep->placeholder->selectBlock),
        div($lang->thinkstep->label->linkCurrent),
        div(setID('zin_thinkstep_link_picker_3_column'), setClass('select-column mx-2')),
        div($lang->thinkstep->label->columnLinkBlock),
        div(setID('zin_thinkstep_link_picker_3_columnBlock'), setClass('multicolumn-block ml-2')),
        btn
        (
            setClass('remove-condition bg-primary-100 w-4 h-4 text-primary ml-4 p-0.5 rounded-full'),
            icon(setClass('text-sm'), 'close')
        )
    ), btn(setClass('text-primary add-condition max-w-max p-0 border-0'), set::disabled(count($multicolumnItems) == 1), icon(setClass('mt-0.5'),'plus'), count($multicolumnItems) > 1 ? on::click()->call('addCondition') : null, div($lang->thinkstep->addConditions))),
    div
    (
        setClass('text-danger link-tips hidden'),
        $lang->thinkstep->error->linkBlock
    ),
    div
    (
        setClass('bg-gray-100 px-6 py-4 link-3c'),
        thinkVennLink(set::wizard($wizard))
    )
);
